# Generated by roxygen2: do not edit by hand

export(bark)
export(bark_mat)
export(sim.Circle)
export(sim.Friedman1)
export(sim.Friedman2)
export(sim.Friedman3)
export(sim_Friedman1)
export(sim_Friedman2)
export(sim_Friedman3)
export(sim_circle)
import(stats)
useDynLib(bark, .registration = TRUE, .fixes="C_")
